# WYSIWYG

## Quels enjeux ?

Permettre l'édition, mais limiter les options graphiques (ni couleurs, ni tailles, ni typos).

Fonctionnalités :
- intégration d'images dans le corps du texte, en gardant la trace du blob active storage, et en les intégrant dans la liste des dépendances.
- intégration de vidéos.
- intégration d'autres formats (Tweets...).

## Solutions techniques

### ActionText

Avantages :
- active storage intégré
- Trix intégré

Inconvénients :
- Pas de modèle (polymorphic)

### Trix

Avantages :
- intégré à ActionText
- très limité

Inconvénients :
- très limité (target blank, 1 seul niveau de titre, pas d'embed, pas de code source)
- pas extensible

### Summernote

Avantages :
- vaste
- extensible

Inconvénients :
- dépendance jQuery
- pas intégré à ActionText
- moyennement robuste quand on le torture

### Page builder custom

Avantages :
- puissant
- souple

Inconvénients :
- compliqué à construire et maintenir
- compliqué à utiliser


## Benchmark

[Refinery](https://www.refinerycms.com/)


[Spina](https://spinacms.com/)


[Alchemy CMS](https://alchemy-cms.com/)


[Locomotive CMS](https://www.locomotivecms.com/)


## Méthode

### action-text-attachment

Dans la BDD, on stocke cette balise :
```
<action-text-attachment sgid="BAh[...]1df3"
                        content-type="image/jpeg"
                        url="http://demo.osuny:3000/rails/active_storage/blobs/redirect/eyJf[...]0f4a1/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg" filename="domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg"
                        filesize="352931"
                        width="588"
                        height="746"
                        previewable="true"
                        presentation="gallery">
</action-text-attachment>
```

A l'édition, la balise est "remplie" avant affichage, pour avoir une preview.
A l'enregistrement, la balise est vidée.

Etapes normales :
1. A l'import d'une image, ajouter l'action-text-attachement autour
2. A l'enregistrement, déshydrater les action-text-attachements
3. A l'édition, réhydrater les action-text-attachements
4. Après l'enregistrement mettre à jour les blobs attachés à l'objet parent (le post, par exemple)

Etapes de migration :
1. Sauvegarder tous les objets à migrer (rails app:fix)
2. A la sauvegarde, transformer le markup Trix en markup Summernote (application_record)
3. Enlever les scripts de l'application_record
4. Supprimer les champs ActionText dans les modèles
5. Supprimer la table d'ActionText
6. Renommer les champs en enlevant _new

Si un programme a 5 champs summernote avec 3 images dans chaque champ, cela fait 15 attachments à lier au programme.
Si on enlève une image d'un champ, il faut mettre à jour la liste pour avoir les 14 bons attachments.

### Le pdf

### Code HTML cible

```
<h2>Titre</h2>
<p>
  Texte normal<br><b>Texte en gras</b><br><i>Texte en italique<br><br></i>
  <action-text-attachment sgid="BAh7CEkiCGdpZAY6BkVUSSJUZ2lkOi8vb3N1bnkvQWN0aXZlU3RvcmFnZTo6QmxvYi9hYWUyNDI5OC1kNDE2LTQ2YWMtYTRlNS02ZjY4ZGU2MjFiZDE_ZXhwaXJlc19pbgY7AFRJIgxwdXJwb3NlBjsAVEkiD2F0dGFjaGFibGUGOwBUSSIPZXhwaXJlc19hdAY7AFQw--7e8ead4d79f455499f1d73e8d53a4b8e81a21df3" content-type="image/jpeg" url="http://demo.osuny:3000/rails/active_storage/blobs/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58" filename="domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg" filesize="352931" width="588" height="746" previewable="true" presentation="gallery">
    <figure class="attachment attachment--preview attachment--jpg">
      <picture>
        <source srcset="/rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBPZ2wzWldKd09ndHlaWE5wZW1WSklna3hNREErQmpvR1JWUTZESEYxWVd4cGRIbHBTdz09IiwiZXhwIjpudWxsLCJwdXIiOiJ2YXJpYXRpb24ifX0=--7d11fdd26322fef8959415f46d5e2c6d6763b4c0/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 100w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBPZ2wzWldKd09ndHlaWE5wZW1WSklna3lNREErQmpvR1JWUTZESEYxWVd4cGRIbHBTdz09IiwiZXhwIjpudWxsLCJwdXIiOiJ2YXJpYXRpb24ifX0=--a168bab53ac15a2905527eb11f95949a389acb1c/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 200w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBPZ2wzWldKd09ndHlaWE5wZW1WSklna3pNREErQmpvR1JWUTZESEYxWVd4cGRIbHBTdz09IiwiZXhwIjpudWxsLCJwdXIiOiJ2YXJpYXRpb24ifX0=--4b9a30812493d514292baecb297418b8bd855aee/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 300w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBPZ2wzWldKd09ndHlaWE5wZW1WSklna3pOelUrQmpvR1JWUTZESEYxWVd4cGRIbHBTdz09IiwiZXhwIjpudWxsLCJwdXIiOiJ2YXJpYXRpb24ifX0=--48741cf975fbaab98c2a79ad9249fddfe9293fe7/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 375w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBPZ2wzWldKd09ndHlaWE5wZW1WSklnazFOelkrQmpvR1JWUTZESEYxWVd4cGRIbHBTdz09IiwiZXhwIjpudWxsLCJwdXIiOiJ2YXJpYXRpb24ifX0=--5492208d61f6b3036b78bd49f55fac2ca32b93a2/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 576w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBPZ2wzWldKd09ndHlaWE5wZW1WSklnazJOREErQmpvR1JWUTZESEYxWVd4cGRIbHBTdz09IiwiZXhwIjpudWxsLCJwdXIiOiJ2YXJpYXRpb24ifX0=--d496b5648ebb9aca3502ad8a6d27b3b6429e42c1/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 640w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBPZ2wzWldKd09ndHlaWE5wZW1WSklnazNOVEErQmpvR1JWUTZESEYxWVd4cGRIbHBTdz09IiwiZXhwIjpudWxsLCJwdXIiOiJ2YXJpYXRpb24ifX0=--8725b97c0ad6bc0968af27611194dcdc17ff4eab/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 750w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBPZ2wzWldKd09ndHlaWE5wZW1WSklnazNOamcrQmpvR1JWUTZESEYxWVd4cGRIbHBTdz09IiwiZXhwIjpudWxsLCJwdXIiOiJ2YXJpYXRpb24ifX0=--48dbb778f2340e56a7632b8f1336ccfc32059f67/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 768w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBPZ2wzWldKd09ndHlaWE5wZW1WSklnb3hNRGd3UGdZNkJrVlVPZ3h4ZFdGc2FYUjVhVXM9IiwiZXhwIjpudWxsLCJwdXIiOiJ2YXJpYXRpb24ifX0=--45340267c3a4f5c6eb6e09658af2089878efcd65/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 1080w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBPZ2wzWldKd09ndHlaWE5wZW1WSklnb3hNVFV5UGdZNkJrVlVPZ3h4ZFdGc2FYUjVhVXM9IiwiZXhwIjpudWxsLCJwdXIiOiJ2YXJpYXRpb24ifX0=--37c484bd70ad99806e65e246357e6160be86e456/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 1152w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBPZ2wzWldKd09ndHlaWE5wZW1WSklnb3hNakF3UGdZNkJrVlVPZ3h4ZFdGc2FYUjVhVXM9IiwiZXhwIjpudWxsLCJwdXIiOiJ2YXJpYXRpb24ifX0=--a3f5fd9ed58ab144319aaf42b90a528dc04b470c/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 1200w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBPZ2wzWldKd09ndHlaWE5wZW1WSklnb3hNelkyUGdZNkJrVlVPZ3h4ZFdGc2FYUjVhVXM9IiwiZXhwIjpudWxsLCJwdXIiOiJ2YXJpYXRpb24ifX0=--4be3c87ab5835218b0b2826dff232ec8aa5b592a/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 1366w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBPZ2wzWldKd09ndHlaWE5wZW1WSklnb3hORFF3UGdZNkJrVlVPZ3h4ZFdGc2FYUjVhVXM9IiwiZXhwIjpudWxsLCJwdXIiOiJ2YXJpYXRpb24ifX0=--643128f1364aca4fcfd4c20af7c63c093d2ff5a2/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 1440w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBPZ2wzWldKd09ndHlaWE5wZW1WSklnb3hOVE0yUGdZNkJrVlVPZ3h4ZFdGc2FYUjVhVXM9IiwiZXhwIjpudWxsLCJwdXIiOiJ2YXJpYXRpb24ifX0=--9f420467052761e3935c91c4838f2b6f8e6eb564/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 1536w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBPZ2wzWldKd09ndHlaWE5wZW1WSklnb3hOakF3UGdZNkJrVlVPZ3h4ZFdGc2FYUjVhVXM9IiwiZXhwIjpudWxsLCJwdXIiOiJ2YXJpYXRpb24ifX0=--aa2f9aae80d2236cef0cd9a06581432f51f714cd/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 1600w" type="image/webp">
        <source srcset="/rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBTU0lJYW5CbkJqb0dSVlE2QzNKbGMybDZaVWtpQ1RFd01ENEdPd1pVT2d4eGRXRnNhWFI1YVVzPSIsImV4cCI6bnVsbCwicHVyIjoidmFyaWF0aW9uIn19--313a7c16346a180239fd77765da7c4f647d453b2/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 100w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBTU0lJYW5CbkJqb0dSVlE2QzNKbGMybDZaVWtpQ1RJd01ENEdPd1pVT2d4eGRXRnNhWFI1YVVzPSIsImV4cCI6bnVsbCwicHVyIjoidmFyaWF0aW9uIn19--2f4a362b69cd558846bb3bc14127bc06ce0d1e32/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 200w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBTU0lJYW5CbkJqb0dSVlE2QzNKbGMybDZaVWtpQ1RNd01ENEdPd1pVT2d4eGRXRnNhWFI1YVVzPSIsImV4cCI6bnVsbCwicHVyIjoidmFyaWF0aW9uIn19--ea8c619cdcb2c49e24c699f3afd7081d67a75ed1/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 300w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBTU0lJYW5CbkJqb0dSVlE2QzNKbGMybDZaVWtpQ1RNM05UNEdPd1pVT2d4eGRXRnNhWFI1YVVzPSIsImV4cCI6bnVsbCwicHVyIjoidmFyaWF0aW9uIn19--7a0624aabf5c2ea94d9d4d4b4e631eae3d8d3558/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 375w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBTU0lJYW5CbkJqb0dSVlE2QzNKbGMybDZaVWtpQ1RVM05qNEdPd1pVT2d4eGRXRnNhWFI1YVVzPSIsImV4cCI6bnVsbCwicHVyIjoidmFyaWF0aW9uIn19--f1b878caa60d7c6a7e87b9452a8c74a0bb879fdf/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 576w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBTU0lJYW5CbkJqb0dSVlE2QzNKbGMybDZaVWtpQ1RZME1ENEdPd1pVT2d4eGRXRnNhWFI1YVVzPSIsImV4cCI6bnVsbCwicHVyIjoidmFyaWF0aW9uIn19--83a0a0e7a5c2a119633da7ffc882cc4dace106d3/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 640w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBTU0lJYW5CbkJqb0dSVlE2QzNKbGMybDZaVWtpQ1RjMU1ENEdPd1pVT2d4eGRXRnNhWFI1YVVzPSIsImV4cCI6bnVsbCwicHVyIjoidmFyaWF0aW9uIn19--7a22a816c2d2d3cb9f34c283dbb909db842b20e0/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 750w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBTU0lJYW5CbkJqb0dSVlE2QzNKbGMybDZaVWtpQ1RjMk9ENEdPd1pVT2d4eGRXRnNhWFI1YVVzPSIsImV4cCI6bnVsbCwicHVyIjoidmFyaWF0aW9uIn19--cd74d329f9ae28773623b47a9f9caa93fc056868/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 768w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBTU0lJYW5CbkJqb0dSVlE2QzNKbGMybDZaVWtpQ2pFd09EQStCanNHVkRvTWNYVmhiR2wwZVdsTCIsImV4cCI6bnVsbCwicHVyIjoidmFyaWF0aW9uIn19--20e3c54414d34a1da7d4248c452aef369eaeb4f8/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 1080w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBTU0lJYW5CbkJqb0dSVlE2QzNKbGMybDZaVWtpQ2pFeE5USStCanNHVkRvTWNYVmhiR2wwZVdsTCIsImV4cCI6bnVsbCwicHVyIjoidmFyaWF0aW9uIn19--9bee96cd223d8f3433a27932a036a8e4f616cbfd/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 1152w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBTU0lJYW5CbkJqb0dSVlE2QzNKbGMybDZaVWtpQ2pFeU1EQStCanNHVkRvTWNYVmhiR2wwZVdsTCIsImV4cCI6bnVsbCwicHVyIjoidmFyaWF0aW9uIn19--0ac42b83a59af35da540f2773d5c1f2f9586544a/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 1200w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBTU0lJYW5CbkJqb0dSVlE2QzNKbGMybDZaVWtpQ2pFek5qWStCanNHVkRvTWNYVmhiR2wwZVdsTCIsImV4cCI6bnVsbCwicHVyIjoidmFyaWF0aW9uIn19--20459e09316a40d3bb42391432993df1918836ac/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 1366w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBTU0lJYW5CbkJqb0dSVlE2QzNKbGMybDZaVWtpQ2pFME5EQStCanNHVkRvTWNYVmhiR2wwZVdsTCIsImV4cCI6bnVsbCwicHVyIjoidmFyaWF0aW9uIn19--79a39bc0bde78546dce4cabc1acaa7c277e7bfa9/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 1440w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBTU0lJYW5CbkJqb0dSVlE2QzNKbGMybDZaVWtpQ2pFMU16WStCanNHVkRvTWNYVmhiR2wwZVdsTCIsImV4cCI6bnVsbCwicHVyIjoidmFyaWF0aW9uIn19--101113cbf47c3ced10889b0e8aeb11ae1de84591/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 1536w, /rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBTU0lJYW5CbkJqb0dSVlE2QzNKbGMybDZaVWtpQ2pFMk1EQStCanNHVkRvTWNYVmhiR2wwZVdsTCIsImV4cCI6bnVsbCwicHVyIjoidmFyaWF0aW9uIn19--44c74545905c5bf696f398b8a3fe350190ffccd8/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58 1600w" type="image/jpeg">
        <img src="/rails/active_storage/representations/redirect/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaEpJaWxoWVdVeU5ESTVPQzFrTkRFMkxUUTJZV010WVRSbE5TMDJaalk0WkdVMk1qRmlaREVHT2daRlZBPT0iLCJleHAiOm51bGwsInB1ciI6ImJsb2JfaWQifX0=--7ded6863b13eb5e510d9c70772bdf8140070f4a1/eyJfcmFpbHMiOnsibWVzc2FnZSI6IkJBaDdDRG9MWm05eWJXRjBTU0lJYW5CbkJqb0dSVlE2QzNKbGMybDZaVWtpQ2pFMk1EQStCanNHVkRvTWNYVmhiR2wwZVdsTCIsImV4cCI6bnVsbCwicHVyIjoidmFyaWF0aW9uIn19--44c74545905c5bf696f398b8a3fe350190ffccd8/domenico_bruno_de_lobkowitz_watchingwindows_com_08.jpg?website_id=6d8fb0bb-0445-46f0-8954-0e25143e7a58" loading="lazy" decoding="async" width="800">
      </picture>
    </figure>
  </action-text-attachment>
  <a href="https://www.u-bordeaux-montaigne.fr/fr/actualites/vie-etudiante/soutenir-les-etudiant-e-s-les-aides-de-l-universite.html">Lien</a>
</p>
```
